@@ -9,13 +9,16 @@ class rabbitmq_helper():
         self.channel = connection.channel()
 
     def send_message(self,body,quenuName):
-        result = self.channel.queue_declare(queue = 'python-test')
-        self.channel.basic_publish(exchange = '',routing_key = quenuName,body = body)
+        
+        result = self.channel.queue_declare(queue = quenuName,durable = True)
+        self.channel.basic_publish(exchange = '',routing_key = quenuName,body = body,properties=pika.BasicProperties(delivery_mode = 2))
     
     def receive_message(self,name):
         def wrap(func):
             self.message_dict[name] = func;
         return wrap;
+    
+    
     def callback(self,ch, method, properties, body):
         flag = False;
         try:
